@@ -5,7 +5,7 @@
    Tyrell DarkIce
 
    File     : DarkIce.cpp
-   Version  : $Revision: 1.43 $
+   Version  : $Revision: 1.45 $
    Author   : $Author: darkeye $
    Location : $Source: /cvsroot/darkice/darkice/src/DarkIce.cpp,v $
    
@@ -88,6 +88,10 @@
 #include "VorbisLibEncoder.h"
 #endif
 
+#ifdef HAVE_FAAC_LIB
+#include "FaacEncoder.h"
+#endif
+
 
 /* ===================================================  local data structures */
 
@@ -97,7 +101,7 @@
 /*------------------------------------------------------------------------------
  *  File identity
  *----------------------------------------------------------------------------*/
-static const char fileid[] = "$Id: DarkIce.cpp,v 1.43 2005/04/11 19:27:43 darkeye Exp $";
+static const char fileid[] = "$Id: DarkIce.cpp,v 1.45 2005/10/22 10:34:21 darkeye Exp $";
 
 
 /*------------------------------------------------------------------------------
@@ -386,6 +390,8 @@ DarkIce :: configIceCast2 (  const Config      & config,
         const char                * url             = 0;
         const char                * genre           = 0;
         bool                        isPublic        = false;
+        int                         lowpass         = 0;
+        int                         highpass        = 0;
         const char                * localDumpName   = 0;
         FileSink                  * localDumpFile   = 0;
         bool                        fileAddDate     = false;
@@ -395,6 +401,8 @@ DarkIce :: configIceCast2 (  const Config      & config,
             format = IceCast2::oggVorbis;
         } else if ( Util::strEq( str, "mp3") ) {
             format = IceCast2::mp3;
+        } else if ( Util::strEq( str, "aac") ) {
+            format = IceCast2::aac;
         } else {
             throw Exception( __FILE__, __LINE__,
                              "unsupported stream format: ", str);
@@ -455,6 +463,10 @@ DarkIce :: configIceCast2 (  const Config      & config,
         genre       = cs->get( "genre");
         str         = cs->get( "public");
         isPublic    = str ? (Util::strEq( str, "yes") ? true : false) : false;
+        str         = cs->get( "lowpass");
+        lowpass     = str ? Util::strToL( str) : 0;
+        str         = cs->get( "highpass");
+        highpass    = str ? Util::strToL( str) : 0;
         str         = cs->get( "fileAddDate");
         fileAddDate = str ? (Util::strEq( str, "yes") ? true : false) : false;
         
@@ -511,7 +523,9 @@ DarkIce :: configIceCast2 (  const Config      & config,
                                                     bitrate,
                                                     quality,
                                                     sampleRate,
-                                                    channel );
+                                                    channel,
+                                                    lowpass,
+                                                    highpass );
 #endif // HAVE_LAME_LIB
                 break;
 
@@ -534,6 +548,24 @@ DarkIce :: configIceCast2 (  const Config      & config,
 #endif // HAVE_VORBIS_LIB
                 break;
 
+            case IceCast2::aac:
+#ifndef HAVE_FAAC_LIB
+                throw Exception( __FILE__, __LINE__,
+                                "DarkIce not compiled with AAC support, "
+                                "thus can't aac stream: ",
+                                stream);
+#else
+                audioOuts[u].encoder = new FaacEncoder(
+                                                audioOuts[u].server.get(),
+                                                dsp.get(),
+                                                bitrateMode,
+                                                bitrate,
+                                                quality,
+                                                sampleRate,
+                                                dsp->getChannel());
+#endif // HAVE_FAAC_LIB
+                break;
+
             default:
                 throw Exception( __FILE__, __LINE__,
                                 "Illegal stream format: ", format);
@@ -753,7 +785,9 @@ DarkIce :: configFileCast (  const Config      & config )
         int                         highpass        = 0;
 
         format      = cs->getForSure( "format", " missing in section ", stream);
-        if ( !Util::strEq( format, "vorbis") && !Util::strEq( format, "mp3") ) {
+        if ( !Util::strEq( format, "vorbis")
+          && !Util::strEq( format, "mp3")
+          && !Util::strEq( format, "aac") ) {
             throw Exception( __FILE__, __LINE__,
                              "unsupported stream format: ", format);
         }
@@ -804,6 +838,12 @@ DarkIce :: configFileCast (  const Config      & config )
                              "invalid bitrate mode: ", str);
         }
 
+        if (Util::strEq(format, "aac") && bitrateMode != AudioEncoder::abr) {
+            throw Exception(__FILE__, __LINE__,
+                            "currently the AAC format only supports "
+                            "average bitrate mode");
+        }
+
         str         = cs->get( "lowpass");
         lowpass     = str ? Util::strToL( str) : 0;
         str         = cs->get( "highpass");
@@ -858,6 +898,22 @@ DarkIce :: configFileCast (  const Config      & config )
                                                     dsp->getSampleRate(),
                                                     dsp->getChannel() );
 #endif // HAVE_VORBIS_LIB
+        } else if ( Util::strEq( format, "aac") ) {
+#ifndef HAVE_FAAC_LIB
+                throw Exception( __FILE__, __LINE__,
+                                "DarkIce not compiled with AAC support, "
+                                "thus can't aac stream: ",
+                                stream);
+#else
+                audioOuts[u].encoder = new FaacEncoder(
+                                                audioOuts[u].server.get(),
+                                                dsp.get(),
+                                                bitrateMode,
+                                                bitrate,
+                                                quality,
+                                                sampleRate,
+                                                dsp->getChannel());
+#endif // HAVE_FAAC_LIB
         } else {
                 throw Exception( __FILE__, __LINE__,
                                 "Illegal stream format: ", format);
@@ -1011,6 +1067,12 @@ DarkIce :: run ( void )                             throw ( Exception )
   $Source: /cvsroot/darkice/darkice/src/DarkIce.cpp,v $
 
   $Log: DarkIce.cpp,v $
+  Revision 1.45  2005/10/22 10:34:21  darkeye
+  added highpass and lowpass values to icecast2 sections
+
+  Revision 1.44  2005/04/16 21:57:34  darkeye
+  added AAC support through the faac codec, http://www.audiocoding.com/
+
   Revision 1.43  2005/04/11 19:27:43  darkeye
   added option to turn off automatic reconnect feature
 
