@@ -5,7 +5,7 @@
    Tyrell DarkIce
 
    File     : DarkIce.h
-   Version  : $Revision: 1.14 $
+   Version  : $Revision: 1.15 $
    Author   : $Author: darkeye $
    Location : $Source: /cvsroot/darkice/darkice/src/DarkIce.h,v $
    
@@ -58,7 +58,7 @@
 #include "AudioEncoder.h"
 #include "TcpSocket.h"
 #include "CastSink.h"
-#include "Config.h"
+#include "DarkIceConfig.h"
 
 
 /* ================================================================ constants */
@@ -73,7 +73,7 @@
  *  Program main object.
  *
  *  @author  $Author: darkeye $
- *  @version $Revision: 1.14 $
+ *  @version $Revision: 1.15 $
  */
 class DarkIce : public virtual Referable, public virtual Reporter
 {
@@ -309,6 +309,10 @@ class DarkIce : public virtual Referable, public virtual Reporter
   $Source: /cvsroot/darkice/darkice/src/DarkIce.h,v $
 
   $Log: DarkIce.h,v $
+  Revision 1.15  2005/04/04 08:36:17  darkeye
+  commited changes to enable Jack support
+  thanks to Nicholas J. Humfrey, njh@ecs.soton.ac.uk
+
   Revision 1.14  2002/05/28 12:35:41  darkeye
   code cleanup: compiles under gcc-c++ 3.1, using -pedantic option
 
