@@ -5,7 +5,7 @@
    Tyrell DarkIce
 
    File     : IceCast2.cpp
-   Version  : $Revision: 1.11 $
+   Version  : $Revision: 1.12 $
    Author   : $Author: darkeye $
    Location : $Source: /cvsroot/darkice/darkice/src/IceCast2.cpp,v $
    
@@ -67,7 +67,7 @@
 /*------------------------------------------------------------------------------
  *  File identity
  *----------------------------------------------------------------------------*/
-static const char fileid[] = "$Id: IceCast2.cpp,v 1.11 2005/04/11 18:32:32 darkeye Exp $";
+static const char fileid[] = "$Id: IceCast2.cpp,v 1.12 2005/04/16 21:57:34 darkeye Exp $";
 
 
 /*------------------------------------------------------------------------------
@@ -156,6 +156,10 @@ IceCast2 :: sendLogin ( void )                           throw ( Exception )
             str = "application/ogg";
             break;
 
+        case aac:
+            str = "audio/aac";
+            break;
+
         default:
             throw Exception( __FILE__, __LINE__,
                              "unsupported stream format", format);
@@ -255,6 +259,9 @@ IceCast2 :: sendLogin ( void )                           throw ( Exception )
   $Source: /cvsroot/darkice/darkice/src/IceCast2.cpp,v $
 
   $Log: IceCast2.cpp,v $
+  Revision 1.12  2005/04/16 21:57:34  darkeye
+  added AAC support through the faac codec, http://www.audiocoding.com/
+
   Revision 1.11  2005/04/11 18:32:32  darkeye
   changed MIME type to application/ogg, which is now official
 
